## TODO: Separate by time aggregation
## TODO: Build a default path that accounts for:
## variable, system, reference, start date and region name

get_filename <- function(dir, recipe, var, date, agg, file.type) {
  # This function builds the path of the output file based on directory,
  # variable, forecast date, startdate, aggregation, forecast horizon and
  # type of metric/forecast/probability.
  
  if (recipe$Analysis$Horizon == "subseasonal") {
    shortdate <- format(as.Date(as.character(date), "%Y%m%d"), "%V")
    dd <- "week"
  } else {
    shortdate <- format(as.Date(as.character(date), "%Y%m%d"), "%m")
    dd <- "month"
  }

  switch(tolower(agg),
	 "country" = {gg <- "-country"},
         "global" = {gg <- ""})

  if (tolower(recipe$Analysis$Output_format) == 'scorecards') {
    # Define output dir name accordint to Scorecards format
    dict <- read_yaml("conf/output_dictionaries/scorecards.yml")
    # Get necessary names
    system <- dict$System[[recipe$Analysis$Datasets$System$name]]$short_name
    reference <- dict$Reference[[recipe$Analysis$Datasets$Reference$name]]$short_name
    hcst_start <- recipe$Analysis$Time$hcst_start
    hcst_end <- recipe$Analysis$Time$hcst_end

    switch(file.type,
	   "skill" = {type_info <- "-skill_"},
	   "corr"  = {type_info <- "-corr_"},
	   "exp"   = {type_info <- paste0("_", date, "_")},
	   "obs"   = {type_info <- paste0("-obs_", date, "_")},
	   "percentiles" = {type_info <- "-percentiles_"},
	   "probs" = {type_info <- paste0("-probs_", date, "_")},
	   "bias"  = {type_info <- paste0("-bias_", date, "_")})

    # Build file name
    file <- paste0("scorecards_", system, "_", reference, "_",
		   var, type_info, hcst_start, "-", hcst_end, "_s", shortdate)
  } else {
    switch(file.type,
  	   "skill" = {file <- paste0(var, gg, "-skill_", dd, shortdate)},
  	   "corr"  = {file <- paste0(var, gg, "-corr_", dd, shortdate)},
  	   "exp"   = {file <- paste0(var, gg, "_", date)},
  	   "obs"   = {file <- paste0(var, gg, "-obs_", date)},
  	   "percentiles" = {file <- paste0(var, gg, "-percentiles_", dd, 
  	          			 shortdate)},
  	   "probs" = {file <- paste0(var, gg, "-probs_", date)},
  	   "bias"  = {file <- paste0(var, gg, "-bias_", date)})
  }

  return(paste0(dir, file, ".nc"))

}

get_dir <- function(recipe, agg = "global") {
  # This function builds the path for the output directory. The output
  # directories will be subdirectories within outdir, organized by variable,
  # startdate, and aggregation.

  ## TODO: Get aggregation from recipe

  outdir <- paste0(recipe$Run$output_dir, "/outputs/")
  ## TODO: multivar case
  variable <- recipe$Analysis$Variables$name

  if (tolower(recipe$Analysis$Output_format) == 'scorecards') {
    # Define output dir name accordint to Scorecards format
    dict <- read_yaml("conf/output_dictionaries/scorecards.yml")
    system <- dict$System[[recipe$Analysis$Datasets$System$name]]$short_name
    dir <- paste0(outdir, "/", system, "/", variable, "/")

  } else {
    # Default generic output format based on FOCUS
    if (!is.null(recipe$Analysis$Time$fcst_year)) {
      if (tolower(recipe$Analysis$Horizon) == 'decadal') {
        #PROBLEM: decadal doesn't have sdate
        fcst.sdate <- paste0(recipe$Analysis$Time$fcst_year, collapse = '_')
      } else {
        fcst.sdate <- paste0(recipe$Analysis$Time$fcst_year,
    	                   recipe$Analysis$Time$sdate)
      }
    } else {
      if (tolower(recipe$Analysis$Horizon) == 'decadal') {
        #PROBLEM: decadal doesn't have sdate
        fcst.sdate <- paste0("hcst-", paste(recipe$Analysis$Time$hcst_start,
					    recipe$Analysis$Time$hcst_end,
					    sep = '_'))
      } else {
        fcst.sdate <- paste0("hcst-", recipe$Analysis$Time$sdate)
      }
    }
  
    calib.method <- tolower(recipe$Analysis$Workflow$Calibration$method)
    store.freq <- recipe$Analysis$Variables$freq
    
    switch(tolower(agg),
  	 "country" = {dir <- paste0(outdir, "/", calib.method, "-",
  				    store.freq, "/", variable, 
  	             		    "_country/", fcst.sdate, "/")},
  	 "global" = {dir <- paste0(outdir, "/", calib.method, "-", 
  				   store.freq, "/", variable, "/",
  				   fcst.sdate, "/")})
  }
  return(dir)

}
