write_autosubmit_conf <- function(recipe, nchunks) {
  # Function to write autosubmit configuration from an Auto-S2S recipe
  expid <- recipe$Run$auto_conf$expid
  template_dir <- "autosubmit/conf/"
  conf_dest_dir <- paste0("/esarchive/autosubmit/", expid, "/conf/")
  # Modify the configuration files according to the info in the recipe
  for (file in list.files(template_dir)) {
    # Define destionation directory and file name accordin to expid
    conf_type <- strsplit(file, split = "[.]")[[1]][1]
    extension <- strsplit(file, split = "[.]")[[1]][2]
    dest_file <- paste0(conf_type, "_", expid, ".", extension)
    dest_dir <- paste0("/esarchive/autosubmit/", expid, "/")
    # Read configuration file
    conf <- read.config(file = paste0(template_dir, file))
    if (conf_type == "autosubmit") {
      ## Section 1: autosubmit.conf
      ## expid, email notifications and address
      conf$config$EXPID <- expid
      if (recipe$Run$auto_conf$email_notifications) {
	conf$mail$NOTIFICATIONS <- "True"
      } else {
	conf$mail$NOTIFICATIONS <- "False"
      }
      conf$mail$TO <- recipe$Run$auto_conf$email_address
    } else if (conf_type == "expdef") {
      ## Section 2: expdef
      ## expid, numchunks, project_type?, project_destination = auto-s2s
      conf$DEFAULT$EXPID <- expid
      conf$experiment$DATELIST <- format(Sys.Date(), "%Y%m%d")
      conf$experiment$NUMCHUNKS <- nchunks
      conf$local$PROJECT_PATH <- recipe$Run$code_dir
    } else if (conf_type == "jobs") {
      ## Section 3: jobs
      ## wallclock, notify_on, platform?, processors
      conf$verification$WALLCLOCK <- recipe$Run$auto_conf$wallclock
      if (recipe$Run$auto_conf$notify_completed) {
        conf$verification$NOTIFY_ON <- paste(conf$verification$NOTIFY_ON,
					     "COMPLETED")
      }
      if (recipe$Run$auto_conf$notify_failed) {
	conf$verification$NOTIFY_ON <- paste(conf$verification$NOTIFY_ON,
					     "FAILED")
      }
      conf$verification$PROCESSORS <- recipe$Run$auto_conf$processors_per_job # ncores?
    } else if (conf_type == "platforms") {
      ## Section 4: platform configuration
      ## nord3v2 configuration... platform name? user, processors_per_node
      conf$nord3v2$USER <- recipe$Run$auto_conf$hpc_user
    } else if (conf_type == "proj") {
      ## Section 5: proj
      ## modules? Info that goes on script, e.g. output directory
      conf$common$OUTDIR <- recipe$Run$output_dir
    }
    # Write config file inside autosubmit dir
    write.config(conf, paste0(conf_dest_dir, dest_file), write.type = "ini")
    Sys.chmod(paste0(conf_dest_dir, dest_file), mode = "755", use_umask = F)
  }
  info(recipe$Run$logger,
       paste("##### AUTOSUBMIT CONFIGURATION WRITTEN FOR", expid, "#####"))
  print(paste("Please SSH into bscesautosubmit01 or bscesautosubmit02 and run",
	      "the following commands:"))
  print("module load autosubmit/3.14.0-foss-2015a-Python-2.7.9")
  print(paste("autosubmit create", expid))
  print(paste("nohup autosubmit run", expid, "& disown"))
}
